.. _echt:

ECHT
####

Bijv. clozapine kan de volgende potentieel dodelijk aandoeningen veroorzaken:

Neutropenia (tekort witte bloedcellen)
Myocarditis (ontsteking hartspier)
Cardiomyopathy (ook hartspier)
Hypotension (lage bloeddruk)
Bradycardia (trage hartslag)
Syncope (flauwvallen)
Cardiac arrest (hartstilstand)
Neuroleptic Malignant Syndrome (NMS)
Constipation (dikke darm verstopping)
Intestinal Obstruction (darm problemen)
Fecal Impaction (vastzittend stront)
Paralytic Ileus (ook voedsel vastzittend in de darm)
